@@ -125,7 +125,7 @@ atk_component_base_init (AtkComponentIface *class)
 
 
 /**
- * atk_component_add_focus_handler: (skip)
+ * atk_component_add_focus_handler:
  * @component: The #AtkComponent to attach the @handler to
  * @handler: The #AtkFocusHandler to be attached to @component
  *
@@ -133,8 +133,9 @@ atk_component_base_init (AtkComponentIface *class)
  * when this object receives focus events (in or out). If the handler is
  * already added it is not added again
  *
- * Deprecated: 2.9.4: If you need to track when an object gains or
- * lose the focus, use the #AtkObject::state-change "focused" notification instead.
+ * Deprecated: This method is deprecated since ATK version 2.9.4. If
+ * you need to track when an object gains or lose the focus, use
+ * state-changed:focused notification instead.
  *
  * Returns: a handler id which can be used in atk_component_remove_focus_handler()
  * or zero if the handler was already added.
@@ -164,8 +165,9 @@ atk_component_add_focus_handler (AtkComponent    *component,
  * functions to be executed when this object receives focus events 
  * (in or out).
  *
- * Deprecated: 2.9.4: If you need to track when an object gains or
- * lose the focus, use the #AtkObject::state-change "focused" notification instead.
+ * Deprecated: This method is deprecated since ATK version 2.9.4. If
+ * you need to track when an object gains or lose the focus, use
+ * state-changed:focused notification instead.
  *
  **/
 void
@@ -226,8 +228,7 @@ atk_component_contains (AtkComponent    *component,
  * Gets a reference to the accessible child, if one exists, at the
  * coordinate point specified by @x and @y.
  *
- * Returns: (nullable) (transfer full): a reference to the accessible
- * child, if one exists
+ * Returns: (transfer full): a reference to the accessible child, if one exists
  **/
 AtkObject*
 atk_component_ref_accessible_at_point (AtkComponent    *component,
@@ -249,18 +250,15 @@ atk_component_ref_accessible_at_point (AtkComponent    *component,
 /**
  * atk_component_get_extents:
  * @component: an #AtkComponent
- * @x: (out) (optional): address of #gint to put x coordinate
- * @y: (out) (optional): address of #gint to put y coordinate
- * @width: (out) (optional): address of #gint to put width
- * @height: (out) (optional): address of #gint to put height
+ * @x: address of #gint to put x coordinate
+ * @y: address of #gint to put y coordinate
+ * @width: address of #gint to put width
+ * @height: address of #gint to put height
  * @coord_type: specifies whether the coordinates are relative to the screen
  * or to the components top level window
  *
  * Gets the rectangle which gives the extent of the @component.
  *
- * If the extent can not be obtained (e.g. a non-embedded plug or missing
- * support), all of x, y, width, height are set to -1.
- *
  **/
 void
 atk_component_get_extents    (AtkComponent    *component,
@@ -297,29 +295,19 @@ atk_component_get_extents    (AtkComponent    *component,
 
   if (iface->get_extents)
     (iface->get_extents) (component, real_x, real_y, real_width, real_height, coord_type);
-  else
-    {
-      *real_x = -1;
-      *real_y = -1;
-      *real_width = -1;
-      *real_height = -1;
-    }
 }
 
 /**
  * atk_component_get_position:
  * @component: an #AtkComponent
- * @x: (out) (optional): address of #gint to put x coordinate position
- * @y: (out) (optional): address of #gint to put y coordinate position
+ * @x: address of #gint to put x coordinate position
+ * @y: address of #gint to put y coordinate position
  * @coord_type: specifies whether the coordinates are relative to the screen
  * or to the components top level window
  *
  * Gets the position of @component in the form of 
  * a point specifying @component's top-left corner.
  *
- * If the position can not be obtained (e.g. a non-embedded plug or missing
- * support), x and y are set to -1.
- *
  * Deprecated: Since 2.12. Use atk_component_get_extents() instead.
  **/
 void
@@ -347,24 +335,16 @@ atk_component_get_position   (AtkComponent    *component,
 
   if (iface->get_position)
     (iface->get_position) (component, real_x, real_y, coord_type);
-  else
-    {
-      *real_x = -1;
-      *real_y = -1;
-    }
 }
 
 /**
  * atk_component_get_size:
  * @component: an #AtkComponent
- * @width: (out) (optional): address of #gint to put width of @component
- * @height: (out) (optional): address of #gint to put height of @component
+ * @width: address of #gint to put width of @component
+ * @height: address of #gint to put height of @component
  *
  * Gets the size of the @component in terms of width and height.
  *
- * If the size can not be obtained (e.g. a non-embedded plug or missing
- * support), width and height are set to -1.
- *
  * Deprecated: Since 2.12. Use atk_component_get_extents() instead.
  **/
 void
@@ -393,11 +373,6 @@ atk_component_get_size       (AtkComponent    *component,
 
   if (iface->get_size)
     (iface->get_size) (component, real_width, real_height);
-  else
-    {
-      *real_width = -1;
-      *real_height = -1;
-    }
 }
 
 /**
@@ -533,13 +508,10 @@ atk_component_set_extents   (AtkComponent    *component,
  * @x: x coordinate
  * @y: y coordinate
  * @coord_type: specifies whether the coordinates are relative to the screen
- * or to the component's top level window
- *
- * Sets the position of @component.
- *
- * Contrary to atk_component_scroll_to, this does not trigger any scrolling,
- * this just moves @component in its parent.
+ * or to the components top level window
  *
+ * Sets the postition of @component.
+ * 
  * Returns: %TRUE or %FALSE whether or not the position was set or not
  **/
 gboolean
@@ -585,68 +557,6 @@ atk_component_set_size       (AtkComponent    *component,
     return FALSE;
 }
 
-/**
- * atk_component_scroll_to:
- * @component: an #AtkComponent
- * @type: specify where the object should be made visible.
- *
- * Makes @component visible on the screen by scrolling all necessary parents.
- *
- * Contrary to atk_component_set_position, this does not actually move
- * @component in its parent, this only makes the parents scroll so that the
- * object shows up on the screen, given its current position within the parents.
- *
- * Returns: whether scrolling was successful.
- *
- * Since: 2.30
- */
-gboolean
-atk_component_scroll_to (AtkComponent  *component,
-                         AtkScrollType  type)
-{
-  AtkComponentIface *iface = NULL;
-  g_return_val_if_fail (ATK_IS_COMPONENT (component), FALSE);
-
-  iface = ATK_COMPONENT_GET_IFACE (component);
-
-  if (iface->scroll_to)
-    return (iface->scroll_to) (component, type);
-
-  return FALSE;
-}
-
-/**
- * atk_component_scroll_to_point:
- * @component: an #AtkComponent
- * @coords: specify whether coordinates are relative to the screen or to the
- * parent object.
- * @x: x-position where to scroll to
- * @y: y-position where to scroll to
- *
- * Move the top-left of @component to a given position of the screen by
- * scrolling all necessary parents.
- *
- * Returns: whether scrolling was successful.
- *
- * Since: 2.30
- */
-gboolean
-atk_component_scroll_to_point (AtkComponent *component,
-                               AtkCoordType  coords,
-                               gint          x,
-                               gint          y)
-{
-  AtkComponentIface *iface = NULL;
-  g_return_val_if_fail (ATK_IS_COMPONENT (component), FALSE);
-
-  iface = ATK_COMPONENT_GET_IFACE (component);
-
-  if (iface->scroll_to_point)
-    return (iface->scroll_to_point) (component, coords, x, y);
-
-  return FALSE;
-}
-
 static gboolean
 atk_component_real_contains (AtkComponent *component,
                              gint         x,
