@@ -17,8 +17,34 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include "config.h"
+
 #include "atkstreamablecontent.h"
 
+/**
+ * SECTION:atkstreamablecontent
+ * @Short_description: The ATK interface which provides access to
+ *  streamable content.
+ * @Title:AtkStreamableContent
+ *
+ * An interface whereby an object allows its backing content to be
+ * streamed to clients.  Typical implementors would be images or
+ * icons, HTML content, or multimedia display/rendering widgets.
+ *
+ * Negotiation of content type is allowed. Clients may examine the
+ * backing data and transform, convert, or parse the content in order
+ * to present it in an alternate form to end-users.
+ *
+ * The AtkStreamableContent interface is particularly useful for
+ * saving, printing, or post-processing entire documents, or for
+ * persisting alternate views of a document. If document content
+ * itself is being serialized, stored, or converted, then use of the
+ * AtkStreamableContent interface can help address performance
+ * issues. Unlike most ATK interfaces, this interface is not strongly
+ * tied to the current user-agent view of the a particular document,
+ * but may in some cases give access to the underlying model data.
+ */
+
 GType
 atk_streamable_content_get_type (void)
 {
@@ -70,7 +96,7 @@ atk_streamable_content_get_n_mime_types (AtkStreamableContent *streamable)
  * Gets the character string of the specified mime type. The first mime
  * type is at position 0, the second at position 1, and so on.
  *
- * Returns : a gchar* representing the specified mime type; the caller
+ * Returns: a gchar* representing the specified mime type; the caller
  * should not free the character string.
  **/
 const gchar*
